@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '2.3609';
+our $VERSION = '2.3611';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -21,7 +21,6 @@ my @wpi_c_functions = qw(
     lcdDisplay          lcdCursor           lcdCursorBlink
     lcdSendCommand      lcdPosition         lcdDefChar
     lcdPutChar          lcdPuts             setInterrupt
-    softPwmCreate       softPwmWrite        softPwmStop
     sr595Setup          bmp180Setup         bmp180Pressure
     bmp180Temp          analogRead          analogWrite
     physPinToWpi        wiringPiVersion     ads1115Setup
@@ -38,12 +37,12 @@ my @wpi_perl_functions = qw(
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
-    set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
-    analog_read     analog_write    pin_mode            phys_to_wpi
+    set_interrupt   bmp180_setup    bmp180_pressure     bmp180_temp
+    shift_reg_setup analog_read     analog_write        pin_mode
     ads1115_setup   spi_setup       spi_data            i2c_setup
     i2c_interface   i2c_read        i2c_read_byte       i2c_read_word
     i2c_write       i2c_write_byte  i2c_write_word      testChar
+    phys_to_wpi
 );
 
 our @EXPORT_OK;
@@ -59,24 +58,6 @@ sub new {
     return bless {}, shift;
 }
 
-# soft PWM functions
-
-sub soft_pwm_create {
-    shift if @_ == 4;
-    my ($pin, $value, $range) = @_;
-    softPwmCreate($pin, $value, $range);
-}
-sub soft_pwm_write {
-    shift if @_ == 3;
-    my ($pin, $value) = @_;
-    softPwmWrite($pin, $value);
-}
-sub soft_pwm_stop {
-    shift if @_ == 2;
-    my $pin = shift;
-    softPwmStop($pin);
-}
-
 # interrupt functions
 
 sub set_interrupt {
@@ -358,7 +339,7 @@ sub i2c_write_byte {
         die "i2c_write_byte() requires a \$data param\n";
     }
 
-    return wiringPiI2CWriteReg8($fd, $reg);
+    return wiringPiI2CWriteReg8($fd, $reg, $data);
 }
 sub i2c_write_word {
     shift if @_ > 3;
@@ -374,7 +355,7 @@ sub i2c_write_word {
         die "i2c_write_word() requires a \$data param\n";
     }
 
-    return wiringPiI2CWriteReg16($fd, $reg);
+    return wiringPiI2CWriteReg16($fd, $reg, $data);
 }
 
 # SPI functions
@@ -505,10 +486,9 @@ versions, but are still 100% compatible.
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
-    set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup pin_mode        analog_read         analog_write
-    bmp180_setup    bmp180_pressure bmp180_temp         phys_to_wpi
-    ads1115_setup   spi_setup       spi_data
+    set_interrupt   pin_mode        analog_read         analog_write
+    shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
+    ads1115_setup   spi_setup       spi_data            phys_to_wpi
 
 =head1 EXPORT_TAGS
 
@@ -532,10 +512,6 @@ See L</BOARD FUNCTIONS>.
 
 See L</LCD FUNCTIONS>.
 
-=head2 SOFTWARE PWM
-
-See L</SOFT PWM FUNCTIONS>.
-
 =head2 INTERRUPT
 
 See L</INTERRUPT FUNCTIONS>.
@@ -1008,47 +984,6 @@ Mandatory: The file descriptor integer returned by C<lcd_init()>.
 
 Mandatory: A string to display.
 
-=head1 SOFT PWM FUNCTIONS
-
-Note: The software PWM functionality is experimental, and from what I've
-tested, not very reliable, so I'd stay away from this at this time.
-
-Software Pulse Width Modulation is not the same as hardware PWM. It should not
-be used for critical things as it's frequency isn't 100% stable.
-
-This software PWM allows you to use PWM on ANY GPIO pin, not just the single
-hardware pin available.
-
-=head2 soft_pwm_create($pin, $initial_value, $range)
-
-Creates a new software PWM thread that runs outside of your main application.
-
-Parameters:
-
-    $pin
-
-Mandatory: The pin number, in the pin numbering scheme dictated by whichever
-C<setup*()> routine you used.
-
-    $initial_value
-
-Optional: A value between C<0> and C<$range>.
-
-    $range
-
-Optional: Look at this like a dial. We start at C<0> and the dial has turned
-completely when we hit the C<$range> integer. If not sent in, defaults to
-C<1023>.
-
-=head2 soft_pwm_write($pin, $value)
-
-Sets the C<HIGH> frequency on C<pin> to whatever is in C<$value>. The value must
-be lower than what was set in the C<$range> parameter to C<soft_pwm_create()>.
-
-=head2 soft_pwm_stop($pin)
-
-Turns off software PWM on the C<$pin>.
-
 =head1 INTERRUPT FUNCTIONS
 
 =head2 set_interrupt($pin, $edge, $callback)
@@ -1476,13 +1411,13 @@ Takes no parameters, returns the byte value as an unsigned int.
 
 Same as L</digitalReadByte>, but reads from the second group of eight GPIO pins.
 
-head1 AUTHOR
+=head1 AUTHOR
 
 Steve Bertrand, E<lt>steveb@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Steve Bertrand
+Copyright (C) 2017 by Steve Bertrand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
